#!/usr/bin/env python3
from flask_marshmallow.sqla import auto_field

from models import User, StreamResource
from marshm import ma
from marshmallow import fields


"""
Marshmallow schemas
"""


__author__ = "@tormakris"
__copyright__ = "Copyright 2020, videON Team"
__module_name__ = "schemas"
__version__text__ = "1"


class UserSchema(ma.Schema):
    """
    Parameters:
     - name (string)
     - passowrd (string)
    """

    name = fields.String(required=True)
    password = fields.String(required=True)


class UserMetadataSchema(ma.SQLAlchemyAutoSchema):
    """
    Marshmallow schema generated
    """
    class Meta:
        model = User
        exclude = ('timestamp', 'password', 'id',)
    creation_date = auto_field("timestamp", dump_only=False)


class IngestInputSchema(ma.Schema):
    outputNeighbours = fields.List(fields.UUID(), required=True)


class EncodeInputSchema(ma.Schema):
    inputNeighbour = fields.UUID(required=True)
    outputNeighbours = fields.List(fields.UUID(), required=True)
    bitrate = fields.Integer(required=False)
    width = fields.Integer(required=False)
    height = fields.Integer(required=False)


class RestreamInputSchema(ma.Schema):
    inputNeighbour = fields.UUID(required=True)
    outputURLs = fields.List(fields.String(), required=True)


class StreamResourceSchema(ma.SQLAlchemyAutoSchema):
    """
    Marshmallow schema generated
    """
    class Meta:
        model = StreamResource
        exclude = ('output_urls', 'parent_id', 'children',)
    outputURLs = auto_field('output_urls', dump_only=False)
    inputNeighbour = auto_field('parent_id', dump_only=False)
    outputNeighbours = auto_field('children', dump_only=False)
